@@ -36,7 +36,12 @@ impl Handler<Subscribe> for CommitMonitor {
     type Result = ();
 
     // A message comes in when a client subscribes to a subject.
-    fn handle(&mut self, msg: Subscribe, _: &mut Context<Self>) {
+    #[tracing::instrument(
+        name = "handle_subscribe",
+        skip_all,
+        fields(to = %msg.subject, agent = %msg.agent)
+    )]
+    fn handle(&mut self, msg: Subscribe, _ctx: &mut Context<Self>) {
         // check if the agent has the rights to subscribe to this resource
         if let Ok(resource) = self.store.get_resource(&msg.subject) {
             match atomic_lib::hierarchy::check_read(&self.store, &resource, &msg.agent) {
@@ -47,11 +52,11 @@ impl Handler<Subscribe> for CommitMonitor {
                         HashSet::new()
                     };
                     set.insert(msg.addr);
-                    log::info!("handle subscribe {} ", msg.subject);
+                    // tracing::info!("handle subscribe {} ", msg.subject);
                     self.subscriptions.insert(msg.subject.clone(), set);
                 }
                 Err(unauthorized_err) => {
-                    log::info!(
+                    tracing::info!(
                         "Not allowed {}  to subscribe to {}: {}",
                         &msg.agent,
                         &msg.subject,
@@ -74,19 +79,13 @@ impl Handler<CommitMessage> for CommitMonitor {
     // I want commits to succeed (no 500 response) even if indexing fails,
     // also because performance is imporatant here -
     // dealing with these indexing things synchronously would be too slow.
+    #[tracing::instrument(name = "handle_commit_message", skip_all, fields(subscriptions = &self.subscriptions.len(), s = %msg.commit_response.commit_resource.get_subject()))]
     fn handle(&mut self, msg: CommitMessage, _: &mut Context<Self>) {
-        let target = msg.commit_response.full_commit.subject.clone();
-
-        log::info!(
-            "handle commit for {} with id {}. Current connections: {}",
-            target,
-            msg.commit_response.commit.get_subject(),
-            self.subscriptions.len()
-        );
+        let target = msg.commit_response.commit_struct.subject.clone();
 
         // Notify websocket listeners
         if let Some(subscribers) = self.subscriptions.get(&target) {
-            log::info!(
+            tracing::debug!(
                 "Sending commit {} to {} subscribers",
                 target,
                 subscribers.len()
@@ -95,12 +94,12 @@ impl Handler<CommitMessage> for CommitMonitor {
                 connection.do_send(msg.clone());
             }
         } else {
-            log::info!("No subscribers for {}", target);
+            tracing::debug!("No subscribers for {}", target);
         }
 
         // Update the value index
         msg.commit_response
-            .full_commit
+            .commit_struct
             .apply_changes(msg.commit_response.resource_old.clone(), &self.store, true)
             .unwrap();
 
