@@ -21,6 +21,7 @@ pub fn empty_to_nothing(string: Option<String>) -> Option<String> {
 }
 
 /// Returns the authentication headers from the request
+#[tracing::instrument(skip_all)]
 pub fn get_auth_headers(
     map: &HeaderMap,
     requested_subject: String,
@@ -57,6 +58,7 @@ pub fn get_auth_headers(
 
 /// Checks for authentication headers and returns Some agent's subject if everything is well.
 /// Skips these checks in public_mode and returns Ok(None).
+#[tracing::instrument(skip(appstate))]
 pub fn get_client_agent(
     headers: &HeaderMap,
     appstate: &AppState,
