@@ -20,7 +20,11 @@ pub fn config_routes(app: &mut actix_web::web::ServiceConfig, config: &Config) {
                 }))
                 .to(handlers::single_page_app::single_page),
         )
-        .service(web::scope("/upload").route("", web::post().to(handlers::upload::upload_handler)))
+        .service(
+            web::resource("/upload")
+                .guard(actix_web::guard::Method(Method::POST))
+                .to(handlers::upload::upload_handler),
+        )
         .service(web::resource("/tpf").to(handlers::tpf::tpf))
         .service(
             web::resource("/commit")
@@ -39,7 +43,7 @@ pub fn config_routes(app: &mut actix_web::web::ServiceConfig, config: &Config) {
                 .to(handlers::search::search_index_rdf),
         );
     }
-    app.service(web::resource("/{path:[^{}]+}").to(handlers::resource::get_resource))
+    app.service(web::resource("/{path:[^{}]+}").to(handlers::resource::handle_get_resource))
         // Also allow the home resource (not matched by the previous one)
-        .service(web::resource("/").to(handlers::resource::get_resource));
+        .service(web::resource("/").to(handlers::resource::handle_get_resource));
 }
